@@ -2,5 +2,5 @@ mod token_waiter;
 mod waiter;
 mod waiter_map;
 
-pub use token_waiter::TokenWaiter;
+pub use token_waiter::{TokenWaiter, ID};
 pub use waiter_map::{WaiterGuard, WaiterMap};
